About
=====

*Atmodeller* is a Python package that leverages `JAX <https://docs.jax.dev/en/latest/>`_ to compute the partitioning of volatiles between a planetary atmosphere and its rocky interior. It is released under `The GNU General Public License v3.0 or later <https://www.gnu.org/licenses/gpl-3.0.en.html>`_. Community development is strongly encouraged.

If you use *Atmodeller* please cite :cite:t:`BTT25`. An accompanying ArXiv preprint is available at `2507.00499 <https://arxiv.org/abs/2507.00499>`_. In addition, please consult the *Atmodeller* source code for citations related to specific components, such as solubility laws and real gas equations of state. Thermodynamic data are sourced from :cite:t:`MZG02`.

Authors
-------

* Dan J. Bower (lead developer, ETH Zurich)
* Maggie A. Thompson (ETH Zurich/Carnegie)
* Kaustubh Hakim (KU Leuven/Royal Observatory of Belgium)
* Meng Tian (LMU Munich)
* Paolo A. Sossi (ETH Zurich)

Funding
-------

Atmodeller was created as part of a SERI-funded ERC Starting grant '2ATMO' granted to P. Sossi (Contract no. MB22.00033), with additional funding provided through a Swiss National Science Foundation (SNSF) Eccellenza Professorship (#203668).